<!DOCTYPE html><html xmlns:ng="http://angularjs.org" xmlns:app="ignored" class="no-js"><head><meta charset="utf-8"><meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1"></head><title>Buildbot</title><meta name="description" content="Buildbot web UI"><meta name="viewport" content="initial-scale=1, minimum-scale=1, user-scalable=no, maximum-scale=1, width=device-width"><link rel="stylesheet" href="styles.css"><link rel="icon" href="img/favicon.ico"><body ng-cloak ng-app="app"><gl-page-with-sidebar><gl-topbar><gl-topbar-contextual-actions></gl-topbar-contextual-actions><loginbar></loginbar></gl-topbar><connectionstatus></connectionstatus><ui-view></ui-view></gl-page-with-sidebar></body><script src="scripts.js?_1460136173521"></script>{% for app in config.plugins -%}<script src="{{app}}/scripts.js"></script><link rel="stylesheet" href="{{app}}/styles.css"><script>angular.module('app').requires.push('{{app}}')</script>{% endfor %}<script>angular.module("app").constant("config", {{configjson|safe}})</script></html>